@@ -8,7 +8,13 @@
 #' @param overwrite Allows overwriting the destination table. Cannot be \code{TRUE} if \code{append} is also \code{TRUE}.
 #' @param append Allow appending to the destination table. Cannot be \code{TRUE} if \code{overwrite} is also \code{TRUE}. Existing Athena DDL file type will be retained
 #'               and used when uploading data to AWS Athena. If parameter \code{file.type} doesn't match AWS Athena DDL file type a warning message will be created 
-#'               notifying user and \code{RAthena} will use the file type for the Athena DDL. 
+#'               notifying user and \code{RAthena} will use the file type for the Athena DDL. When appending to an Athena DDL that has been created outside of \code{RAthena}.
+#'               \code{RAthena} can support the following SerDes and Data Formats.
+#' \itemize{
+#' \item{\strong{csv/tsv:} \href{https://docs.aws.amazon.com/athena/latest/ug/lazy-simple-serde.html}{LazySimpleSerDe}}
+#' \item{\strong{parquet:} \href{https://docs.aws.amazon.com/athena/latest/ug/parquet.html}{Parquet SerDe}}
+#' \item{\strong{json:} \href{https://docs.aws.amazon.com/athena/latest/ug/json.html}{JSON SerDe Libraries}}
+#' }
 #' @param field.types Additional field types used to override derived types.
 #' @param partition Partition Athena table (needs to be a named list or vector) for example: \code{c(var1 = "2019-20-13")}
 #' @param s3.location s3 bucket to store Athena table, must be set as a s3 uri for example ("s3://mybucket/data/"). 
@@ -100,7 +106,7 @@ Athena_write_table <-
     if(max.batch < 0) stop("`max.batch` has to be greater than 0", call. = F)
     
     if(!is.infinite(max.batch) && file.type == "parquet") message("Info: parquet format is splittable and AWS Athena can read parquet format ",
-                                                                  "in parrellel. `max.batch` is used for compressed `gzip` format which is not splittable.")
+                                                                  "in parallel. `max.batch` is used for compressed `gzip` format which is not splittable.")
     
     # use default s3_staging directory is s3.location isn't provided
     if (is.null(s3.location)) s3.location <- conn@info$s3_staging
@@ -151,7 +157,9 @@ Athena_write_table <-
                                                                                        "\t" = "tsv",
                                                                                        stop("RAthena currently only supports csv and tsv delimited format")),
                          "org.apache.hadoop.hive.ql.io.parquet.serde.ParquetHiveSerDe" = "parquet",
+                         # json library support: https://docs.aws.amazon.com/athena/latest/ug/json.html#hivejson
                          "org.apache.hive.hcatalog.data.JsonSerDe" = "json",
+                         "org.openx.data.jsonserde.JsonSerDe" = "json",
                          stop("Unable to append onto table: ", name,"\n", tbl_info$StorageDescriptor$SerdeInfo$SerializationLibrary,
                               ": Is currently not supported by RAthena", call. = F))
 
@@ -227,8 +235,7 @@ Athena_write_table <-
       dbClearResult(rs)}
     
     # Repair table
-    res <- dbExecute(conn, paste0("MSCK REPAIR TABLE ", name))
-    dbClearResult(res)
+    repair_table(conn, name, partition, s3.location, append)
     
     on.exit({lapply(FileLocation, unlink)
       if(!is.null(conn@info$expiration)) time_check(conn@info$expiration)})
@@ -253,8 +260,7 @@ upload_data <- function(con, x, name, partition = NULL, s3.location= NULL,  file
   tryCatch(s3 <- con@ptr$resource("s3"),
            error = function(e) py_error(e))
   for (i in 1:length(x)){
-    tryCatch(s3$Bucket(s3_key[[1]])$upload_file(Filename = x[i], Key = s3_key[[2]][i]),
-             error = function(e) py_error(e))}
+    retry_api_call(s3$Bucket(s3_key[[1]])$upload_file(Filename = x[i], Key = s3_key[[2]][i]))}
   invisible(NULL)
 }
 
@@ -372,7 +378,7 @@ setMethod("sqlData", "AthenaConnection",
 #' @return \code{sqlCreateTable} returns data.frame's \code{DDL} in the \code{\link[DBI]{SQL}} format.
 #' @seealso \code{\link[DBI]{sqlCreateTable}}
 #' @examples 
-#' \donttest{
+#' \dontrun{
 #' # Note: 
 #' # - Require AWS Account to run below example.
 #' # - Different connection methods can be used please see `RAthena::dbConnect` documnentation
@@ -387,12 +393,12 @@ setMethod("sqlData", "AthenaConnection",
 #' 
 #' # Create DDL for iris data.frame with partition
 #' sqlCreateTable(con, "iris", iris, 
-#'                partition = c("timestamp" = format(Sys.Date(), "%Y%m%d")),
+#'                partition = "timestamp",
 #'                s3.location = "s3://path/to/athena/table")
 #'                
 #' # Create DDL for iris data.frame with partition and file.type parquet
 #' sqlCreateTable(con, "iris", iris, 
-#'                partition = c("timestamp" = format(Sys.Date(), "%Y%m%d")),
+#'                partition = "timestamp",
 #'                s3.location = "s3://path/to/athena/table",
 #'                file.type = "parquet")
 #' 
@@ -435,7 +441,7 @@ setMethod("sqlCreateTable", "AthenaConnection",
     SQL(paste0(
       "CREATE EXTERNAL TABLE ", table, " (\n",
       "  ", paste(field, collapse = ",\n  "), "\n)\n",
-      partitioned(partition),
+      partitioned(con, partition),
       FileType(file.type), "\n",
       "LOCATION ",s3.location, "\n",
       header(file.type, compress)
@@ -463,9 +469,9 @@ createFields <- function(con, fields, field.types) {
 }
 
 # Helper function partition
-partitioned <- function(obj = NULL){
+partitioned <- function(con, obj = NULL){
   if(!is.null(obj)) {
-    obj <- paste(obj, "STRING", collapse = ", ")
+    obj <- paste(quote_identifier(con, obj), "STRING", collapse = ", ")
     paste0("PARTITIONED BY (", obj, ")\n") }
 }
 
@@ -558,3 +564,70 @@ s3_upload_location <- function(x,
   list(s3_info$bucket,
        sprintf("%s%s%s%s%s", s3_info$key, schema, name, partition, FileName))
 }
+
+# repair table using MSCK REPAIR TABLE for non partitioned and ALTER TABLE for partitioned tables
+repair_table <- function(con, name, partition = NULL, s3.location = NULL, append = FALSE){
+  if (grepl("\\.", name)) {
+    schema <- gsub("\\..*", "" , name)
+    table1 <- gsub(".*\\.", "" , name)
+  } else {
+    schema <- con@info$dbms.name
+    table1 <- name}
+  
+  # format table name for special characters
+  table <- paste0(quote_identifier(con,  c(schema,table1)), collapse = ".")
+  
+  if (is.null(partition)){
+    query <- SQL(paste0("MSCK REPAIR TABLE ", table))
+    res <- dbExecute(con, query)
+    dbClearResult(res)
+  } else {
+    # formatting s3 partitions
+    s3_partition <- unlist(partition)
+    s3_partition <- paste(names(s3_partition), unname(s3_partition), sep = "=", collapse = "/")
+    
+    # s3 bucket and key split
+    s3_info <- split_s3_uri(s3.location)
+    s3_info$key <- gsub("/$", "", s3_info$key)
+    
+    # Append data to existing s3 location
+    if(append) {s3.location <- sprintf("s3://%s/%s/%s/", s3_info$bucket, s3_info$key, s3_partition)
+    } else {
+      if (s3_partition != "") s3_partition <- paste0(s3_partition, "/")
+      split_key <- unlist(strsplit(s3_info$key,"/"))
+      
+      # remove name from s3 key
+      if(split_key[length(split_key)] == table1 || length(split_key) == 0)  split_key <- split_key[-length(split_key)]
+      
+      # remove schema from s3 key
+      if(any(schema == split_key))  split_key <- split_key[-which(schema == split_key)]
+      
+      s3_info$key <- paste(split_key, collapse = "/")
+      if (s3_info$key != "") s3_info$key <- paste0(s3_info$key, "/")
+      
+      # s3 folder
+      schema <- paste0(schema, "/")
+      table1 <- paste0(table1, "/")
+      
+      # S3 new syntax #73
+      s3.location <- sprintf("s3://%s/%s%s%s%s", s3_info$bucket, s3_info$key, schema, table1, s3_partition)
+    }
+    
+    partition_names <- quote_identifier(con, names(partition))
+    partition <- dbQuoteString(con, partition)
+    partition <- paste0(partition_names, " = ", partition, collapse = ", ")
+    s3.location <- dbQuoteString(con, s3.location)
+    
+    query <- SQL(paste0("ALTER TABLE ", table, " ADD IF NOT EXISTS\nPARTITION (", partition, ")\nLOCATION ", s3.location))
+    res <- dbSendQuery(con, query)
+    poll_result <- poll(res)
+    dbClearResult(res)
+    
+    # If query failed, due to glue permissions default back to msck repair table
+    if(poll_result$QueryExecution$Status$State == "FAILED" && grepl(".*glue.*BatchCreatePartition.*AccessDeniedException", poll_result$QueryExecution$Status$StateChangeReason)) {
+      query <- SQL(paste0("MSCK REPAIR TABLE ", table))
+      res <- dbExecute(con, query)
+      dbClearResult(res)
+    } else if (poll_result$QueryExecution$Status$State == "FAILED") stop(poll_result$QueryExecution$Status$StateChangeReason, call. = FALSE)
+  }
+}
