@@ -7,7 +7,9 @@ boto <- NULL
   register_s3_method("dplyr", "db_save_query", "AthenaConnection")
   register_s3_method("dbplyr", "db_copy_to", "AthenaConnection")
   register_s3_method("dbplyr", "sql_translate_env", "AthenaConnection")
-  
+  register_s3_method("dbplyr", "sql_escape_string", "AthenaConnection")
+  register_s3_method("dbplyr", "db_explain", "AthenaConnection")
+  register_s3_method("dbplyr", "db_query_fields", "AthenaConnection")
 }
 
 register_s3_method <- function(pkg, generic, class, fun = NULL) {
